all.Phems<-function(){
     cat("\n")
     note_for_Phe_input()
     cat("\n")
     note_for_close_window()
     PheMSpar<-data.frame(subject=c(1,2),bw=c(0),D=c(0),tau=c(0),c=c(0))
     PheMSpar<-edit(PheMSpar)
##     PheMSpar<-zmscheck(PheMSpar)
     cat("\n")
     Phe.ms(length(PheMSpar$subject),PheMSpar$c,PheMSpar$tau,PheMSpar$D,PheMSpar$bw)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_Phe_output()
     show(samplesStats("*"))
     cat("\n")
     C<-Phecpr(PheMSpar$D,PheMSpar$tau)  
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     show(coutput)  
     cat("\n") 
     cal.again()
}